==> node-typescript_3.8.3.orig.tar.gz: TypeScript-3.8.3/tests/baselines/reference/genericPrototypeProperty3.js <==
//// [genericPrototypeProperty3.ts]
class BaseEvent {
    target: {};
}

class MyEvent<T> extends BaseEvent { // T is instantiated to any in the prototype, which is assignable to {}
    target: T;
}
class BaseEventWrapper {
    t: BaseEvent;
}

class MyEventWrapper extends BaseEventWrapper {
    t: MyEvent<any>;
}

//// [genericPrototypeProperty3.js]
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var BaseEvent = /** @class */ (function () {
    function BaseEvent() {
    }
    return BaseEvent;
}());
var MyEvent = /** @class */ (function (_super) {
    __extends(MyEvent, _super);
    function MyEvent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return MyEvent;
}(BaseEvent));
var BaseEventWrapper = /** @class */ (function () {
    function BaseEventWrapper() {
    }
    return BaseEventWrapper;
}());
var MyEventWrapper = /** @class */ (function (_super) {
    __extends(MyEventWrapper, _super);
    function MyEventWrapper() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return MyEventWrapper;
}(BaseEventWrapper));

==> node-typescript_4.1.3.orig.tar.gz: TypeScript-4.1.3/tests/baselines/reference/genericPrototypeProperty3.js <==
//// [genericPrototypeProperty3.ts]
class BaseEvent {
    target: {};
}

class MyEvent<T> extends BaseEvent { // T is instantiated to any in the prototype, which is assignable to {}
    target: T;
}
class BaseEventWrapper {
    t: BaseEvent;
}

class MyEventWrapper extends BaseEventWrapper {
    t: MyEvent<any>;
}

//// [genericPrototypeProperty3.js]
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var BaseEvent = /** @class */ (function () {
    function BaseEvent() {
    }
    return BaseEvent;
}());
var MyEvent = /** @class */ (function (_super) {
    __extends(MyEvent, _super);
    function MyEvent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return MyEvent;
}(BaseEvent));
var BaseEventWrapper = /** @class */ (function () {
    function BaseEventWrapper() {
    }
    return BaseEventWrapper;
}());
var MyEventWrapper = /** @class */ (function (_super) {
    __extends(MyEventWrapper, _super);
    function MyEventWrapper() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return MyEventWrapper;
}(BaseEventWrapper));
